MuteOnFocusLoss = MuteOnFocusLoss or {
	is_focused = true
}
MuteOnFocusLoss._modpath = MuteOnFocusLoss._modpath or ModPath
MuteOnFocusLoss._menupath = MuteOnFocusLoss._menupath or (MuteOnFocusLoss._modpath .. "menu/options.json")
MuteOnFocusLoss._settingspath = MuteOnFocusLoss._settingspath or (SavePath .. "muteonfocusloss.json")
MuteOnFocusLoss._default_loc_path = MuteOnFocusLoss._default_loc_path or (MuteOnFocusLoss._modpath .. "localization/english.json")

MuteOnFocusLoss.default_settings = {
	mute_music = true,
	mute_sfx = true,
	mute_vc = true
}
MuteOnFocusLoss.settings = table.deep_map_copy(MuteOnFocusLoss.default_settings)

--[[
function MuteOnFocusLoss:do_cache_user_settings()
	local umgr = managers.user
	self.volume_music = umgr:get_setting("music_volume")
	self.volume_sfx = umgr:get_setting("sfx_volume")
	self.volume_vc = umgr:get_setting("voice_volume")
end
--]]

function MuteOnFocusLoss:Load()
	local file = io.open(self._settingspath, "r")
	if file then
		for k, v in pairs(json.decode(file:read("*all"))) do
			self.settings[k] = v
		end
	else
		self:Save()
	end
end

function MuteOnFocusLoss:Save()
	local file = io.open(self._settingspath,"w+")
	if file then
		file:write(json.encode(self.settings))
		file:close()
	end
end

function MuteOnFocusLoss:OnFocusChanged(is_focused)
	local menumgr = managers.menu
	local umgr = managers.user
	local settings = self.settings
	
	local music_vol
	local sfx_vol
	local vc_vol
	if is_focused then
	--[[
		if settings.mute_music then
			menumgr:music_volume_changed("music_volume",0,0)
		end
		if settings.mute_sfx then
			menumgr:sfx_volume_changed("sfx_volume",0,0)
		end
		if settings.mute_vc then
			menumgr:voice_volume_changed("voice_volume",0,0)
		end
	--]]
	
		music_vol = umgr:get_setting("music_volume")
		sfx_vol = umgr:get_setting("sfx_volume")
		vc_vol = umgr:get_setting("voice_volume")
	else
		music_vol = 0
		sfx_vol = 0
		vc_vol = 0
	end
	
	if settings.mute_music then
		menumgr:music_volume_changed("music_volume",0,music_vol)
	end
	if settings.mute_sfx then
		menumgr:sfx_volume_changed("sfx_volume",0,sfx_vol)
	end
	if settings.mute_vc then
		menumgr:voice_volume_changed("voice_volume",0,vc_vol)
	end
	--[[
	if is_focused then
		umgr:set_setting("music_volume",self.volume_music)
		umgr:set_setting("sfx_volume",self.volume_sfx)
		umgr:set_setting("voice_volume",self.volume_vc)
	else
		umgr:set_setting("music_volume",0)
		umgr:set_setting("sfx_volume",0)
		umgr:set_setting("voice_volume",0)
	end
	--]]
end

function MuteOnFocusLoss:Update(t,dt)
	local is_focused = Application:in_focus()
	if is_focused ~= self.is_focused then
		self.is_focused = is_focused
		self:OnFocusChanged(is_focused)
	end
end

function MuteOnFocusLoss:GetSetting(setting)
	return self.settings[setting]
end

Hooks:Add("LocalizationManagerPostInit", "mofl_LocalizationManagerPostInit", function(loc)
	if not BeardLib then
		loc:load_localization_file(MuteOnFocusLoss._default_loc_path)
	end
end)

Hooks:Add("MenuManagerInitialize", "mofl_MenuManagerInitialize", function(menu_manager)
	MenuCallbackHandler.callback_mofl_toggle_mute_music = function(self,item)
		MuteOnFocusLoss.settings.mute_music = item:value() == "on"
		MuteOnFocusLoss:Save()
	end
	
	MenuCallbackHandler.callback_mofl_toggle_mute_sfx = function(self,item)
		MuteOnFocusLoss.settings.mute_sfx = item:value() == "on"
		MuteOnFocusLoss:Save()
	end
	MenuCallbackHandler.callback_mofl_toggle_mute_vc = function(self,item)
		MuteOnFocusLoss.settings.mute_vc = item:value() == "on"
		MuteOnFocusLoss:Save()
	end
	MuteOnFocusLoss:Load()
	
	MenuHelper:LoadFromJsonFile(MuteOnFocusLoss._menupath, MuteOnFocusLoss, MuteOnFocusLoss.settings)
end)